@@ -7,7 +7,7 @@ if(!is.null(callplsRglm$modele)){modele <- eval(callplsRglm$modele)} else {model
 if(!is.null(callplsRglm$family)){family <- eval(callplsRglm$family)} else {family <- NULL}
 if(typeboot=="plsmodel"){
 temp.bootplsRglm <- if(!(sim=="permutation")){boot(data=dataset, statistic=coefs.plsRglm, sim=sim, stype=stype, R=R, nt=nt, modele=modele, family=family,...)} else {
-boot(data=dataset, statistic=permcoefs.plsRglm, sim=sim, stype=stype, R=R, nt=nt, modele=modele)}
+boot(data=dataset, statistic=permcoefs.plsRglm, sim=sim, stype=stype, R=R, nt=nt, modele=modele, family=family)}
 indices.temp.bootplsRglm <- !is.na(temp.bootplsRglm$t[,1])
 temp.bootplsRglm$t=temp.bootplsRglm$t[indices.temp.bootplsRglm,]
 temp.bootplsRglm$R=sum(indices.temp.bootplsRglm)
@@ -16,7 +16,7 @@ return(temp.bootplsRglm)
 }
 if(typeboot=="fmodel_np"){
 temp.bootplsRglm <- if(!(sim=="permutation")){boot(data=dataset, statistic=coefs.plsRglm, sim=sim, stype=stype, R=R, nt=nt, modele=modele, family=family,...)} else {
-boot(data=dataset, statistic=permcoefs.plsRglm, sim=sim, stype=stype, R=R, nt=nt, modele=modele)}
+boot(data=dataset, statistic=permcoefs.plsRglm, sim=sim, stype=stype, R=R, nt=nt, modele=modele, family=family)}
 indices.temp.bootplsRglm <- !is.na(temp.bootplsRglm$t[,1])
 temp.bootplsRglm$t=temp.bootplsRglm$t[indices.temp.bootplsRglm,]
 temp.bootplsRglm$R=sum(indices.temp.bootplsRglm)
@@ -25,7 +25,7 @@ return(temp.bootplsRglm)
 }
 if(typeboot=="fmodel_par"){
 temp.bootplsRglm <- if(!(sim=="permutation")){boot(data=dataset, statistic=coefs.plsRglm, sim=sim, stype=stype, R=R, nt=nt, modele=modele, family=family,...)} else {
-boot(data=dataset, statistic=permcoefs.plsRglm, sim=sim, stype=stype, R=R, nt=nt, modele=modele)}
+boot(data=dataset, statistic=permcoefs.plsRglm, sim=sim, stype=stype, R=R, nt=nt, modele=modele, family=family)}
 indices.temp.bootplsRglm <- !is.na(temp.bootplsRglm$t[,1])
 temp.bootplsRglm$t=temp.bootplsRglm$t[indices.temp.bootplsRglm,]
 temp.bootplsRglm$R=sum(indices.temp.bootplsRglm)
