@@ -1,5 +1,5 @@
 infcrit.dof <- function(modplsR,naive=FALSE){
-if(!is.null(modplsR$weights)){naive=TRUE}
+if(!(is.null(modplsR$weights) | identical(modplsR$weights,rep(1L,modplsR$nr)) | identical(modplsR$weights,rep(1,modplsR$nr)))){naive=TRUE}
 if(modplsR$na.miss.X|modplsR$na.miss.Y){naive=TRUE}
 if(!naive){
 tempmodplsR_dof <- plsR.dof(modplsR,naive=FALSE)
@@ -11,7 +11,7 @@ tempAIC.naive <- aic.dof(modplsR$RSS,modplsR$nr,tempmodplsR_naive$DoF,tempmodpls
 tempBIC.naive <- bic.dof(modplsR$RSS,modplsR$nr,tempmodplsR_naive$DoF,tempmodplsR_naive$sigmahat)
 tempGMDL.naive <- gmdl.dof(tempmodplsR_naive$sigmahat,modplsR$nr,tempmodplsR_naive$DoF,tempmodplsR_naive$yhat)
 InfCrit.dof <- t(rbind(tempmodplsR_dof$DoF,tempmodplsR_dof$sigmahat,tempAIC.dof,tempBIC.dof,tempGMDL.dof,tempmodplsR_naive$DoF,tempmodplsR_naive$sigmahat,tempAIC.naive,tempBIC.naive,tempGMDL.naive))
-dimnames(InfCrit.dof) <- list(paste("Nb_Comp_",0:modplsR$computed_nt), c("DoF.dof","sigmahat.dof","AIC.dof", "BIC.dof", "GMDL.dof","DoF.naive","sigmahat.naive","AIC.naive", "BIC.naive", "GMDL.naive"))
+dimnames(InfCrit.dof) <- list(paste("Nb_Comp_",0:modplsR$computed_nt,sep=""), c("DoF.dof","sigmahat.dof","AIC.dof", "BIC.dof", "GMDL.dof","DoF.naive","sigmahat.naive","AIC.naive", "BIC.naive", "GMDL.naive"))
 } else {InfCrit.dof <- NULL}
 return(InfCrit.dof)
 }
